==> 01.98.zip: tweet_live-01.98/web/fens2012-museo-culture-opendata/config.php <==
<?php
$config = array(
    'tracking_keywords' => array('#museoweb'),
    'hashtag'    => '#fens2012 #museoweb',
   	'date'   => '19.06.2012',
   	'heure'   => '17h30-19h30',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Futur En Seine 2012 - Open Data et Culture",
	'abstract'   => "Séminaire &laquo;&nbsp;Muséologie, muséographie et nouvelles formes d'adresse au public&nbsp;&raquo;&nbsp;:<br /><b>Open Data et Culture.</b><br/>le 20/06/2012 de 17h00 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "<h3>Séminaire &laquo;&nbsp;Muséologie, muséographie et nouvelles formes d'adresse au public&nbsp;&raquo;.</h3>
<p>le 19/06/2012 de 17h00 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite</p>
<p>Au delà de l’Open Data (ouverture des
données) qui, en France, rappelons-le,
ne se veut pas simplement administratif mais
ouvert à la Culture, les apports du Web, qu’il
soit social ou sémantique, semblent aujourd’hui
acceptés et reconnus comme une opportunité
par un nombre croissant d’acteurs dans le
domaine de la culture et des musées. Données et
métadonnées, en particulier sur le Web où elles
circulent en abondance, accaparent aujourd’hui
les réflexions de tous ceux qui ont cure de l’impact
des nouveaux dispositifs numériques d’adresse
au public. Aussi nous a-t-il paru indispensable
d’associer à ce séminaire plusieurs institutions
intéressées à ces enjeux afin d’aborder la
problématique de l’avenir des musées qui passe
elle-même par une réflexion sur le devenir du
Web. Cette séance, qui clôture ce séminaire
annuel, abordera plus particulièrement les
questions juridiques - licences, données,
contexte français, Open Data culturel - parfois
sensibles dans la collaboration entre institutions
culturelles et communautés de la contribution.</p>
<h3>Intervenants&nbsp;:</h3>
<ul>
    <li><b>Mélanie Dulong de Rosnay</b>, CNRS</li>
    <li><b>Rémi Mathis</b>, Wikimedia</li>
    <li><b>Sonia Zillhardt</b>, Ministère de la culture</li>
</ul>
<h3>Autres événements PolemicTweet sur Futur En Seine 2012</h3>
<ul>
    <li>
        <a href='http://polemictweet.com/fens2012-gamestudies'>Conférence Game Studies&nbsp;? à la française</a>,
        les samedi 16 et dimanche 17 juin 2012 de 09h00 à 20h00, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-designmetadata'>Lancement de l'exposition Design Metadata</a>,
        le lundi 18 juin de 17h00 à 19h30, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-vinyl-numerique'>Table Ronde &laquo;&nbsp;Du vinyl au numérique, quelles mutations dans la pratique et la consommation de la chanson jeune public&nbsp;?&nbsp;&raquo;</a>,
        le mercredi 20 juin 2012 de 14h30 à 17h00, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-edito-datajournalisme'>Séminaire &laquo;&nbsp;Nouvelles formes d'éditorialisation&nbsp;&raquo;&nbsp;: Data-Journalisme et visualisation de données</a>,
        le mercredi 20 juin 2012 de 17h30 à 19h30, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-wiid'>Rencontre WIID - Who Is Interaction Design?</a>,
        le vendredi 22 juin 2012 de 18h00 à 21h00, Petite Salle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-mashupfilmfestival'>Mashup Film Festival&nbsp;: Conférence &laquo;&nbsp;Les enjeux des pratiques collaboratives et de la contribution</a>,
        le samedi 23 juin 2012 de 14h30 à 16h00, Forum des Images
    </li>
</ul>",
   	'link' => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/',
   	'islive'     => true,
   	'keywords'   => 'futur en seine, muséologie, muséographie, adresse au public, iri, open data, données ouvertes, culture, données culturelles, wikimedia, ministère de la culture, cnrs',
   	'rep' => basename('__DIR__'),
   	'partenaires'=>
"<a href='http://www.futur-en-seine.fr/' class='footerLink' target='_blank'>Futur en Seine 2012</a> 
| <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a> 
| <a href='http://www.culture.gouv.fr/' class='footerLink' target='_blank'>Ministère de la Culture et de la Communication</a> 
| <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a> 
| <a href='http://www.wikimedia.fr/' class='footerLink' target='_blank'>Wikimedia France</a> 
| <a href='http://www.w3.org/' class='footerLink' target='_blank'>W3C</a> 
| <a href='http://www.centrepompidou.fr/' class='footerLink' target='_blank'>Centre Pompidou</a>",

    'client_visual' => 'images/big-museo-fens.jpg',// 480 × 320 pixels
    
 	'head_logo' => 'images/fens-pt.png', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide-museo-fens.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-museo-fens.jpg', // 270 × 150 pixels

 	'archive_title' => "Open Data et Culture.",
 	'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a> au Centre Pompidou<br />le mardi 19 juin 2012 17:00 - 20:00',

    // After the event
	'metadata'    => "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/743934fe-c9db-11e1-9443-00145ea4a2be",
	'protocol_level' => 3,
);

==> V01.99.zip: tweet_live-V01.99/web/fens2012-museo-culture-opendata/config.php <==
<?php
$config = array(
    'tracking_keywords' => array('#museoweb'),
    'hashtag'    => '#fens2012 #museoweb',
   	'date'   => '19.06.2012',
   	'heure'   => '17h30-19h30',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Futur En Seine 2012 - Open Data et Culture",
	'abstract'   => "Séminaire &laquo;&nbsp;Muséologie, muséographie et nouvelles formes d'adresse au public&nbsp;&raquo;&nbsp;:<br /><b>Open Data et Culture.</b><br/>le 20/06/2012 de 17h00 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "<h3>Séminaire &laquo;&nbsp;Muséologie, muséographie et nouvelles formes d'adresse au public&nbsp;&raquo;.</h3>
<p>le 19/06/2012 de 17h00 à 20h00<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite</p>
<p>Au delà de l’Open Data (ouverture des
données) qui, en France, rappelons-le,
ne se veut pas simplement administratif mais
ouvert à la Culture, les apports du Web, qu’il
soit social ou sémantique, semblent aujourd’hui
acceptés et reconnus comme une opportunité
par un nombre croissant d’acteurs dans le
domaine de la culture et des musées. Données et
métadonnées, en particulier sur le Web où elles
circulent en abondance, accaparent aujourd’hui
les réflexions de tous ceux qui ont cure de l’impact
des nouveaux dispositifs numériques d’adresse
au public. Aussi nous a-t-il paru indispensable
d’associer à ce séminaire plusieurs institutions
intéressées à ces enjeux afin d’aborder la
problématique de l’avenir des musées qui passe
elle-même par une réflexion sur le devenir du
Web. Cette séance, qui clôture ce séminaire
annuel, abordera plus particulièrement les
questions juridiques - licences, données,
contexte français, Open Data culturel - parfois
sensibles dans la collaboration entre institutions
culturelles et communautés de la contribution.</p>
<h3>Intervenants&nbsp;:</h3>
<ul>
    <li><b>Mélanie Dulong de Rosnay</b>, CNRS</li>
    <li><b>Rémi Mathis</b>, Wikimedia</li>
    <li><b>Sonia Zillhardt</b>, Ministère de la culture</li>
</ul>
<h3>Autres événements PolemicTweet sur Futur En Seine 2012</h3>
<ul>
    <li>
        <a href='http://polemictweet.com/fens2012-gamestudies'>Conférence Game Studies&nbsp;? à la française</a>,
        les samedi 16 et dimanche 17 juin 2012 de 09h00 à 20h00, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-designmetadata'>Lancement de l'exposition Design Metadata</a>,
        le lundi 18 juin de 17h00 à 19h30, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-vinyl-numerique'>Table Ronde &laquo;&nbsp;Du vinyl au numérique, quelles mutations dans la pratique et la consommation de la chanson jeune public&nbsp;?&nbsp;&raquo;</a>,
        le mercredi 20 juin 2012 de 14h30 à 17h00, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-edito-datajournalisme'>Séminaire &laquo;&nbsp;Nouvelles formes d'éditorialisation&nbsp;&raquo;&nbsp;: Data-Journalisme et visualisation de données</a>,
        le mercredi 20 juin 2012 de 17h30 à 19h30, Salle Triangle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-wiid'>Rencontre WIID - Who Is Interaction Design?</a>,
        le vendredi 22 juin 2012 de 18h00 à 21h00, Petite Salle, Centre Pompidou
    </li>
    <li>
        <a href='http://polemictweet.com/fens2012-mashupfilmfestival'>Mashup Film Festival&nbsp;: Conférence &laquo;&nbsp;Les enjeux des pratiques collaboratives et de la contribution</a>,
        le samedi 23 juin 2012 de 14h30 à 16h00, Forum des Images
    </li>
</ul>",
   	'link' => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/',
   	'islive'     => true,
   	'keywords'   => 'futur en seine, muséologie, muséographie, adresse au public, iri, open data, données ouvertes, culture, données culturelles, wikimedia, ministère de la culture, cnrs',
   	'rep' => basename('__DIR__'),
   	'partenaires'=>
"<a href='http://www.futur-en-seine.fr/' class='footerLink' target='_blank'>Futur en Seine 2012</a> 
| <a href='http://www.capdigital.com/' class='footerLink' target='_blank'>Cap Digital</a> 
| <a href='http://www.culture.gouv.fr/' class='footerLink' target='_blank'>Ministère de la Culture et de la Communication</a> 
| <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a> 
| <a href='http://www.wikimedia.fr/' class='footerLink' target='_blank'>Wikimedia France</a> 
| <a href='http://www.w3.org/' class='footerLink' target='_blank'>W3C</a> 
| <a href='http://www.centrepompidou.fr/' class='footerLink' target='_blank'>Centre Pompidou</a>",

    'client_visual' => 'images/big-museo-fens.jpg',// 480 × 320 pixels
    
 	'head_logo' => 'images/fens-pt.png', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide-museo-fens.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-museo-fens.jpg', // 270 × 150 pixels

 	'archive_title' => "Open Data et Culture.",
 	'archive_description' => 'par l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a> au Centre Pompidou<br />le mardi 19 juin 2012 17:00 - 20:00',

    // After the event
	'metadata'    => "743934fe-c9db-11e1-9443-00145ea4a2be",
//	'protocol_level' => 3,
);
